package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````)14``#0```"<@0````0`!30`(``(
M`"@`%P`6``8````T````-````#0``````0````$```0````$`````P```#0!
M```T`0``-`$``!@````8````!`````$````!````````````````````1'H`
M`$1Z```%`````!````$```#,?0``S(T``,R-``!X`@``I`(```8`````$```
M`@```-1]``#4C0``U(T``/````#P````!@````0````$````3`$``$P!``!,
M`0``)````"0````$````!````%'E=&0```````````````````````````8`
M```0````4N5T9,Q]``#,C0``S(T``#0"```T`@``!`````$````O;&EB+VQD
M+6UU<VPM87)M:&8N<V\N,0`$````%`````,```!'3E4`O=YE_%^'8U@TF<8X
M/50,^3>+J,81````3`````@````(`````9`0`"5`!(`H@!`%H(90A("!``(+
M(`2-.(`208H$"`A,````30```%$```!6````5P```%\```!@````80``````
M``!C````9`````````!E````9@```&D```````````````&O-.AJ?YI\ZM/O
M#L[>1RUOQ=\?+L6;MKB-\0[49-1\=E0\E"'_Y`[9<5@<^J%L8,+E/RRR`8MO
M0OK7A^)'Q@%8[Y=YF$_#F[OCDGQ5PSS29Z_,9H@'<--#1=7L,V+;[16,)<Q_
MJ9R;X*<""FH:GE"_VE<;H^#[20``````````````````````````6!``````
M```#``@```````"0`````````P`2``$``````````````!(````)````````
M```````2````$```````````````$0```/8!`````````````!$```!_`0``
M```````````2````%P``````````````$@```,\!`````````````!(````?
M```````````````2````)@``````````````$@````,"`````````````!(`
M``#;`0`````````````2````+P``````````````(`````T#````````````
M`"$```!'```````````````2````30``````````````$@```%0`````````
M`````!(```#,`@`````````````2````X@(`````````````$@```%L`````
M`````````!(````>`@`````````````2````8@``````````````$@```*0"
M`````````````!(```!I```````````````2````<0``````````````$@``
M`,4"`````````````!(```!Y```````````````2````C0(`````````````
M$@```($``````````````!(```"*```````````````@````VP(`````````
M````$@```*8``````````````!(```"K```````````````2````G`$`````
M````````%@```*L"`````````````!(```!+`@`````````````2````M```
M````````````$@```#T"`````````````!(```!1`P`````````````2````
MM@(`````````````$0````P#`````````````!$```!O`@`````````````2
M````^0(`````````````$@````X#`````````````!$```"[````````````
M```2````Q```````````````$0```(T!`````````````!(```#6````````
M```````B````Y0``````````````(````/L``````````````!(```"L````
M```````````2````6P(`````````````$@`````!`````````````"````"8
M`@`````````````2````&@$`````````````$@```,`!`````````````!(`
M```?`0`````````````2````?0(`````````````$@```"4!````````````
M`!(```"O`0`````````````2````,P$`````````````$@```$0!````````
M`````!(````9`@`````````````2````*@(`````````````$@```$H!````
M`````````!(```!D`@`````````````2````U`(`````````````$@```/$"
M`````````````!(```!9`0`````````````2````%`(`````````````$@``
M`&`!`````````````!(```!G`0`````````````2````"P,`````````````
M(0```'@!`````````````!(```!9!```<)`````````0`!,`!@,``$D3``#<
M`0``$@`*`/`!``!5.````@```!(`"P"3`P``124``*@$```2``H`:00``/DK
M``#,````$@`*`'`#``"]&P``!````!(`"@`-!```61````(````2``@`M@,`
M`.TI```,`@``$@`*`!,$``!$D````````!``$P!!!```P1L``,@!```2``H`
M[@,``$20````````$``3`($#``"%)```P````!(`"@"@`P``A1H``$@````2
M``H`J`,``&TB``!L````$@`*`,P#``")-@``_@```!(`"@#A`P``B1T``"0`
M```2``H`^@,``'"0````````$``3``($``#9(@``4````!(`"@!D!```<)``
M```````0`!,`-@,``$$5``!$````$@`*`"$$``"M'0``&`$``!(`"@#7`P``
M0)````0````1`!(`.@0``$20````````$``2`/,#```E%0```````!(`"@`*
M!```+38``%P````2``H`/P,``&DD```<````$@`*`%H#``#-&@``\````!(`
M"@!.!```B3<``,P````2``H`6`0``'"0````````$``3`"T$``#%'@``J`,`
M`!(`"@``;W!E;F1I<@!M96UC;7``<W1D97)R`')E86QL;V,`86-C97-S`'-N
M<')I;G1F`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K`&=E='!I9`!S
M=')C;7``;65M<V5T`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``<W1R<F-H<@!C
M;&]S961I<@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!V9G!R
M:6YT9@!S=')C:'(`<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?
M9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`7TE435]R96=I
M<W1E<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E
M<G)N;U]L;V-A=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!M96UC<'D`<W1R
M;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S
M869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``<W1R8W!Y
M`')E861D:7(`<W1R=&]K`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!S<')I;G1F
M`%]?;&EB8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C
M+FUU<VPM87)M=C<N<V\N,0!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G
M971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE
M8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!S:&%?=7!D871E`&UY
M7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?<W1A<G0`7U]E;F1?7P!P87)?
M9&EE`'-H85]I;FET`%]?8G-S7W-T87)T7U\`<&%R7V1I<FYA;64`<&%R7VEN
M:71?96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]?8G-S7V5N
M9%]?`%]E;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L
M+T-/4D4``,R-```7````T(T``!<```"\CP``%P```,B/```7````U(\``!<`
M````D```%P```!"0```7````%)```!<````<D```%P```""0```7````))``
M`!<````HD```%P```"R0```7````-)```!<````XD```%P```$"0```7````
MP(\``!4%``#$CP``%08``,R/```5#@``T(\``!4?``#8CP``$R,``-R/```5
M*0``X(\``!4M``#DCP``%2\``.B/```5,0``[(\``!4R``#PCP``%38``/2/
M```5.P``^(\``!4]``#\CP``%4$``-".```6`P``U(X``!8$``#8C@``%@<`
M`-R.```6"```X(X``!8)``#DC@``%@H``.B.```6"P``[(X``!8,``#PC@``
M%@T``/2.```6#@``^(X``!80``#\C@``%A$```"/```6$@``!(\``!83```(
MCP``%A0```R/```6%0``$(\``!86```4CP``%A<``!B/```6&```'(\``!89
M```@CP``%AH``"2/```6&P``*(\``!8<```LCP``%AT``#"/```6'@``-(\`
M`!8@```XCP``%B$``#R/```6(@``0(\``!8D``!$CP``%B4``$B/```6)@``
M3(\``!8G``!0CP``%B@``%2/```6*P``6(\``!8L``!<CP``%BX``&"/```6
M,```9(\``!8Q``!HCP``%C(``&R/```6,P``<(\``!8T``!TCP``%C4``'B/
M```6-P``?(\``!8X``"`CP``%CD``(2/```6.@``B(\``!8\``",CP``%CX`
M`)"/```6/P``E(\``!9```"8CP``%D(``)R/```60P``H(\``!9$``"DCP``
M%D4``*B/```61@``K(\``!9'``"PCP``%D@``+2/```620``N(\``!9+```!
MM;WH`4!P1P3@+>4$X)_E#N"/X`CPON54?@```,:/X@?*C.)4_KSE`,:/X@?*
MC.),_KSE`,:/X@?*C.)$_KSE`,:/X@?*C.(\_KSE`,:/X@?*C.(T_KSE`,:/
MX@?*C.(L_KSE`,:/X@?*C.(D_KSE`,:/X@?*C.(<_KSE`,:/X@?*C.(4_KSE
M`,:/X@?*C.(,_KSE`,:/X@?*C.($_KSE`,:/X@?*C.+\_;SE`,:/X@?*C.+T
M_;SE`,:/X@?*C.+L_;SE`,:/X@?*C.+D_;SE`,:/X@?*C.+<_;SE`,:/X@?*
MC.+4_;SE`,:/X@?*C.+,_;SE`,:/X@?*C.+$_;SE`,:/X@?*C.*\_;SE`,:/
MX@?*C.*T_;SE`,:/X@?*C.*L_;SE`,:/X@?*C.*D_;SE`,:/X@?*C.*<_;SE
M`,:/X@?*C.*4_;SE>$?]YP#&C^('RHSBB/V\Y0#&C^('RHSB@/V\Y0#&C^('
MRHSB>/V\Y0#&C^('RHSB</V\Y0#&C^('RHSB:/V\Y0#&C^('RHSB8/V\Y0#&
MC^('RHSB6/V\Y0#&C^('RHSB4/V\Y0#&C^('RHSB2/V\Y0#&C^('RHSB0/V\
MY0#&C^('RHSB./V\Y0#&C^('RHSB,/V\Y0#&C^('RHSB*/V\Y0#&C^('RHSB
M(/V\Y0#&C^('RHSB&/V\Y0#&C^('RHSB$/V\Y0#&C^('RHSB"/V\Y0#&C^('
MRHSB`/V\Y0#&C^('RHSB^/R\Y0#&C^('RHSB\/R\Y0#&C^('RHSBZ/R\Y0#&
MC^('RHSBX/R\Y0#&C^('RHSBV/R\Y0#&C^('RHSBT/R\Y7A'_><`QH_B!\J,
MXL3\O.4`QH_B!\J,XKS\O.5X1_WG`,:/X@?*C.*P_+SE`,:/X@?*C.*H_+SE
M`,:/X@?*C.*@_+SE`,:/X@?*C.*8_+SE`,:/X@?*C.*0_+SE`,:/X@?*C.*(
M_+SE`,:/X@?*C.*`_+SE`,:/X@?*C.)X_+SE`````$_T@%SPM:WK#`S,^,`/
MB[#-Z08074U>2P62?43K6`:I!:H'J%M,&V@)DT_P``/_]UCO64I\1*)86$L#
MDN-8$4881@23__?&[E5+XU@=>``M9M`=[G`O2TL'F'M$&VC26,4<DOC6,P0P
M0_`#`[#Q@$^"^-8S=]*``/_W5N\#1DE*24QZ1-_X).'?^"3!%FC=Z082"&A\
M1/Y$_$0!*L/I``Z>8,/X#,!C8&7="!\#\0P,`.N"`%'X!$^(0DSX!$_YT=0<
M`"8[3SQ)?T3X:"I&`)9Y1$/X)&#_][3N`"@QT#=-"*Y]1.AH__?J[@1&-$@Q
M1GA$`/`C^4"S,DM[1-AH__=F[__W(.XP2B%+>D336!IH"9M:0$_P``,RT2!&
M"[#PO?_WKNXI2GI$T&`PL__W".\52QWN<"][1!MHTUB#^*Y6B>?X:/_WZN[)
MYZAH$+$!\*_[T><>2#%&>$0`\._XJ&``*,G0\^<;2QM(XUAX1!E&`Y/_]PSN
M!"2CYP$@__?"[O_W,.\R?```5GL``%Y[```@`0``1'L``#@!```T`0````$`
M`')\``"`?```&B@``!PH``!,?```[04``#)\``!D)0``&GP``&YZ``#N>P``
MF"0``!@!``"$)@``3_``"T_P``X#27E$:$8@\`\,Y48`\`+XHG@``!"U`"0"
M1@M)"TAY1`A8A+`*2P*0RUC?^"C``Y,!E%'X#!`#1@"1`YA2^`0;__=0[@2P
M$+UV>0``$`$``/@````$`0``!D@'2P=*>$1[1(-">D0#T`5+TU@#L1A'<$<`
MO[9Z``"T>@``,'D```P!```(2`E+>$1[1!L:V0\'2@'KHP%)$'I$`]`%2]-8
M`[$81W!'`+^,>@``BGH``/QX```L`0``3_2`7!"UK>L,#,SX^`\.2PY,>T0;
M>'Q$H[D-2^-8([$,2WM$&&C_]Q3N__>Y_PI+XU@;L0E(>$3_]V#M`2((2WM$
M&G`0O0"_2GH``,9X```D`0``]GD```@!```B9```''H``$_T@%P(M:WK#`S,
M^/@/!TL'2GM$FU@KL09)!TAY1'A$__?J[;WH"$">YP"_9G@``"@!``#@>0``
MUF,``$_T@%PMZ?A#K>L,#,SXX`\?2X!&>T0`*#;0'DJ;6-/X`)"Y\0`/,=`%
M>`]&`"T8OSTM%+\!)0`E$]'9^`!`;+%.1BI&048@1O_W2NT0N6-=/2L0T%;X
M!$\`+/+1($:]Z/B#!485^`$_`"L8OSTK^=&EZP@%X>>FZPD&`36V$"Q$/F`@
M1KWH^(,$1N?G3$;EYRAX```<`0``3_2`7!"UK>L,#,SX6`\72A=+>D2HL--8
M:48;:">33_```P1&__?([:"Y!)L#]'!#L_4@3QB_L_6`3PW0#4H,2WI$TU@:
M:">;6D!/\``#"]$HL!"]`"#QYP(A($;_]YKLL/J`\$`)Z>?_]]+MDG<``"`!
M``!D=P``3_2`7/"UK>L,#,SX2`\T2C1+>D336*FP&V@GDT_P``,0L0-X!$9;
MN2]*+DMZ1--8&F@GFUI`3_```T_1*;#PO?_W3NP%1@`H[M`H1O_WENR8L\-\
M`/$3!BXK`M%S>``K\]##?"XK+]`@1O_WD.T'1C!&__>,[3A$`C#_]Y[L,T8&
M1AI)(D9Y1/_W;NTP1FE&__<\[0$P,$8%T`2;`_1P0[/U@$\7T/_W@NPP1O_W
M0NTH1O_W9.P`*,O1*$;_]Z#L($;_]Q[MK^=S>"XKS-&S>``KNM#(Y__WD__F
MY__W7.T:=P``(`$```!W``#.(```3_2`7"WI\$>MZPP,S/C8#PQ&5DI62WI$
MTUB"L!MH`9-/\``#"W@%1CTK"+\!-"!&__<T[6E&!D8H1O_WX?Y-3X%&?T0`
M*%30__<H[89"1]D`FT_J@PA(2_]8*W@`*QB_/2L4OP$C`",'T"M&$_@!+P`J
M&+\]*OG16QNP'!A$/FC_]R+L1O@(`.BQ*$8[:%/X"!`0^`$[/2L8OP`K"W`)
MT$H<$/@!.Q%&/2L8OP`K`O@!._;1/2,*1@MP%/@!.P+X`3\`*_G1+4HI2WI$
MTU@::`&;6D!/\``#1=$"L+WH\(<)\?\Y%/@!.PGX`3\`*_G1Z><A2_]8U_@`
M@-CX`#![LT-&4_@$+TE&"?$!"0`J^-$#,8D`&DIZ1!-HN[D!(PA&$V#_]]+K
M@D8`*,S0049/ZHD(0D;_]\[KQ_@`H``CS?@`D`GQ`0E*^"DPAN=`1O_W8NN"
M1CA@`"BUT$_JB0CMYYE&""'6Y__WH.P`OR9V```@`0``^G4``!P!``!R=0``
MPG8``$_T@%PPM:WK#`S,^.`/$D@=[G!/>$0`:!%*$DEZ1%%8A;`*1@.1$$L0
M22!8>T1Y1/_W5.P)2``E>$0`:`Q+#4H-27M$(%AZ1,WI`#5Y1/_W..L%L#"]
M`+^X=0``E'4``)QT```P`0``9%\``+H>``"J(0``FP\``+@>```0M`Q)#$K?
M^#3`>40):'I$'>YP#U+X#$!`6")&"$L)28.P>T1Y1`&4`[!=^`1+__<5O`"_
M1G4``"YT```P`0``\EX``$@>``!/](!<<+6MZPP,S/@``*SU@%S,^```3/@H
M##!*,$NM]0!=AK!Z1--8#?4`410Q&V@+8$_P``/_]_KJ*DPJ2GQ$`ZX#1GI$
M0?(!`3!&`)3_]]#J0?(!`T(<FD(YV`$P.-`-]8!5$#5/](!2*48P1O_W<.L$
M'BW;8!S_]P+K`T9`LZA"`M("&95"(M.K0AW80?(!`I1"'-@B1AA&*4;_]\[K
M`"(#1@)5$4D-2GE$#?4`4(I8%#`1:`)H44!/\``""M$81@WU`%T&L'"]*AF3
M0M[2_]X`(^?G__?$ZP"_T',``"`!```F'@``%!X``$IS``#_]X:_3_2`7"WI
M\$^MZPP,S/@``$SXT`Q@3*WUA5U@2H.P?$0%1E](HE@-]853`J\.1GA$.48$
M,Q)H&F!/\``"__="_2\A!$8H1O_W[.K`L55(*49X1/_W-_XH1E-*4$MZ1`WU
MA5'36`0Q&F@+:%I`3_```T#PCX`-]85=`["]Z/"/,$;_][#J24EY1/_W4NN"
M1@`HW-#?^!R!FO@`,`WQJ`GX1*GQ!`8`*U'0++%11B!&__=*Z@`H/M!01O_W
M4NL"1D,>4T2:18-&/K\`(5)$"O$!`P/3"^"30A%P!-`2^`'-O/$O#_?04$;_
M]SSK@T8H1O_W..M81`$PL/6`7Z?2W_BTP%-&_$1"1D_T@%$P1LWI`,7_]_3I
M`3"P]8!?/-@Y1C!&__?>ZC"Y6?B0/`/T<$.S]0!/&=`@20`@>43_]_KJ@D8`
M*(/0FO@`,``KK='<L2-X+BL%T-_X9*!/\`$+^D3%YV-X`"OFT/7G`2$P1O_W
MP.D`*-_1$D@Q1GA$__>C_3!&__<PZFCGW_@\H$_P`0OZ1*SG__?LZO_>XG(`
M`"`!``!*'0``-!T``*1R```.'0``^AP``)X<``!<'```&!P```P<``#F&P``
M3_2`7!"UK>L,#,SX^`\O(01&__?PZ0"Q1!P@1KWH$$#_]_JY3_2`7#"UK>L,
M#,SX``!,^!@,.DHZ2ZWU@%UZ1(.P#?6`4=-8!#$;:`M@3_```P`H.M`#>`5&
MN[/_]YSJ`3"P]8!?1]@!K"E&($;_][SI($;_]Y#J`3@@1*!""-D`(@+@H$)"
M<`/0$/@!.2\K^-`O(2!&__>NZ7BSH$*$OP`C`W`@1O_WNND?2AU+>D0-]8!1
MTU@$,1IH"VA:0$_P``,KT0WU@%T#L#"]%TH52WI$#?6`4=-8!#$::`MH6D!/
M\``#&M$22'A$#?6`70.PO>@P0/_WD+D`(-;G#4H)2WI$#?6`4=-8!#$::`MH
M6D!/\``#`M$(2'A$YN?_]T+J^G```"`!``"*<```:'```,0:```X<```E!H`
M`$_T@%QPM:WK#`S,^.@/S$K,2WI$S$W36,Q.@K!]1!MH`9-/\``#?D1L1B%&
M,$;_]\?[L+'&2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P
M1O_WL?L`*.C1O$Y^1"%&,$;_]ZG[L+&W2P"8ZU@9:`'K@`-::$'X("``*N_0
M!#-::$/X!"L`*OK1(48P1O_WD_L`*.C1KDY^1"%&,$;_]XO[L+&H2P"8ZU@9
M:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W=?L`*.C1H$Y^1"%&
M,$;_]VW[L+&92P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P
M1O_W5_L`*.C1DDY^1"%&,$;_]T_[L+&*2P"8ZU@9:`'K@`-::$'X("``*N_0
M!#-::$/X!"L`*OK1(48P1O_W.?L`*.C1A$Y^1"%&,$;_]S'[L+%[2P"8ZU@9
M:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W&_L`*.C1=DY^1"%&
M,$;_]Q/[L+%L2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P
M1O_W_?H`*.C1:$Y^1"%&,$;_]_7ZL+%=2P"8ZU@9:`'K@`-::$'X("``*N_0
M!#-::$/X!"L`*OK1(48P1O_WW_H`*.C16DY^1"%&,$;_]]?ZL+%.2P"8ZU@9
M:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_WP?H`*.C13$Y^1"%&
M,$;_][GZL+$_2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P
M1O_WH_H`*.C1/DY^1"%&,$;_]YOZL+$P2P"8ZU@9:`'K@`-::$'X("``*N_0
M!#-::$/X!"L`*OK1(48P1O_WA?H`*.C1,$@A1GA$__=^^@%&&+$M2'A$__=X
M^RQ((49X1/_W<_H!1ABQ*DAX1/_W;?LI2"%&>$3_]VCZ`4:PL29(>$3_]V+[
M)4H12WI$TU@::`&;6D!/\``#%=$A22)(>41X1`*PO>AP0/_W3[L?2"%&>$3_
M]TKZ`48`*.30'$AX1/_W0_O?Y__WE.CJ;P``(`$``.!O``!Z&@``'`$``$@:
M```4&@``Y!D``+`9``"$&0``Y!@``!@9``#H&```N!@````8``!*&```)A@`
M`$@8``!0&```4A@``'X7``#\;```3!@``+(7```F&```L!<``$_T@%P`M:WK
M#`S,^/`/$TH32WI$$TB#L--8:49X1!MH`9-/\``#__?W^4"Q`'@`*!B_,"@,
MOP$@`""`\`$`"DH'2WI$TU@::`&;6D!/\``#`M$#L%WX!/O_]S+H0FP``"`!
M```@%P``$FP``$_T@%P/M`"UK>L,#,SX\`\+20Q+>43+6(.P&V@!DT_P``,$
MJE+X!!L'2PA(>T0`DAM8&&C^]U;O_R#^]YSO`+_4:P``(`$``+QK``#\````
M3_``#"WI\$=/](`^K>L,#*SK#@ZL]8!<S/@``/1%^=%.^#@,`B%`34!,K?6`
M/8:P?40L60WU@#8D:'1A3_``!``B`",`D8!&_O>\[@$X8?$`!_H7@.KG<YL:
MF[)30)L:!O$4!F+K`@+&&F?K`@<`+TO;3_`("0.MP/(!"0`A,D8[1D!&`)'^
M]Y[NL?'_/PB_L/'_/T'02D8I1D!&_O=:[T,<-M`'*";9"#@L&"/2W_B`H/I$
M`N`!/*Q"'-,((E%&($;^]TKN`"CUT60;H!E'Z^1Q&$H52WI$#?6`---8%#0:
M:"-H6D!/\``#&M$-]8`]!K"]Z/"'MO6`-F?Q``>W\?\_"+\6]8`_N-%/\/\P
M`4;?YPE(>$3_]TO_"$AX1/_W1__^]W#O`+]H:P``(`$``"9L``#":@``_!4`
M`.05``!/](!<"+6MZPP,S/CX#_[W8._^][[N`+$`:`B]3_2`7/"UK>L,#,SX
MV`\D2B1.)4MZ1(6PTUA^1`5&`JDP1AMH`Y-/\``#__?I^!"Q`W@$1HNY'4H;
M2WI$TU@::`.;6D!/\``#*-$I1AA(>$0%L+WH\$#_]].Y*$;^]Q[O!T8@1O[W
M&N\X1`(P_O<L[A!+$4DJ1GM$>40`E`1&_O?\[@Y*"$MZ1--8&F@#FUI`3_``
M`P2_(48P1MG0_O<$[RAJ``"F%0``(`$```)J``!R%0``6A0``%P4``"V:0``
M3_2`7"WI\$^MZPP,S/C`#L>P#?'("M1&W_@(%-_X"$3?^`@D>42*6'Q$!/$,
M`P3Q&`XLK1)H19)/\``"!9"3Z`<`A>@'`+[H#P"LZ`\`GN@#`#`T#?&\"8SH
M`P"4Z`<`B>@'`/)(W_C,@P:N,49X1/A$__=E^""Q`W@$1@`K0/!6@?[WN.[^
M]Q;N`"@`\)*`!V@`+P#PCH`X1O[WH.Y```$P_O>R[3IX!$:!1EJQW_B(L_M$
M($991O[W?NX7^`$O`C0`*O;1W4AX1`+@6O@$#XBQ,4;_]S3X!$8`*/;0`W@`
M*_/0__=X^``H[]`@1O[WN.T$1GBY5?@$2V2Q(W@`*P#P`8$@1O_W9_@`*.[1
M5?@$2P`L\M$@1O[W8.X%1DA&_O=<[@5$!?($12A&_O=L[<WX!)"!1L)+PDE[
M1`"3PDLB1GM$>43^]SCN3_3@<4A&_O<0[@$P!='^]P;N`&@1*$#PV(`Q1DA&
M_O<2[@1&`"@XT+9(!9JV25CX``!+1A)H`&AY1/[WQNT`);)*ITMZ1--8&FA%
MFUI`3_```T#P.X$H1D>PO>CPC_[W6NT'1@`H0/"K@%GX!`M8L3%&_O?`_P`H
M]]`#>``K[M%9^`0+`"CST0T@_O<8[9]/4R($1H%&?T1DYS-I`_1P0[/U@$_`
MT;=I_O<`[H="N]$S:</S"`.S]>!_M=$H1O[W_NP%1I-(,49X1/[WE/\!1@`H
M`/"9@`6;&&C_]RKZ@D8`*`#PD8!01O[WU.T#*(!&$-F(200X4$1Y1/[WO.Q(
MN;CQ!`\`\,V`T$08^`4\+RL`\,>`@4@Q1GA$_O=L_R"Q`W@P*QB_`"L&T0`A
M4$;^]_CL!D8`*&O1>4EY2'E$>$3_]UGX_O>2['=*=TMX27I$W_C@@7A/>$[-
MZ0`">T1*1BA&>43^]X3M^$1_1'Y$$N#^]U;M`V@1*Q31_O=V[(1&`31#1DI&
M.48H1LWI`4;-^`#`_O=L[4_TX'$H1O[W1NT!,.702$;^]TCM9$@I1GA$__<A
M^"A&__<>_D'G'$8%Y_[W:.U```$PQN9-206:6/@!0%M)$FA+1@"0>40@:/[W
M].PLY__W!_Y72CU+>D336!IH19M:0$_P``-GT2!&1["]Z/!/_O>%O`6;T_@`
MH&KG__=#_;'Q``@'1HW;3_``"K#Q"@)H\0`#,$;-^`"@#?'@"_[W%.P&(C!&
M64;^]]CL!BA%T4_TAD,XFL3R03.:0G_T<J]$\DA3N_@$()I"?_1KK[?Q,@)H
M\0`#,$;-^`"@.JS^]_3K*"(P1B%&_O>X["@H)=$Q2C%+,DEZ1`&2*$9*1@"4
M>T1Y1(WX$*'^]^CL@.<%FU]H`"\_]#2O.$;^]_#L`RA_]BZO)TD$.#A$>43^
M]]KK`"@(O[I&(^?^]^CL(DAX1/_WN?P`OUAI``"4:@``(`$``(83```,:0``
M9A0``.@3``#R$P``W!,``-H2``#\````[A,``.YG```P$P``LA,``(H3```"
M$@``6A(``-P1```8%```=A$``$P3``!J$0``5!,``/H3``#\$```$!(``$9F
M``#<$@``/A````@2``#,$0``P!$``$_T@%SPM:WK#`S,^.`/;TIO2WI$TUB#
ML!MH`9-/\``#8$L=[G!/>T0;:&Y&Y5AI2)7X9#`Q1GA$A?AE,/[W+/X0L0-X
M,2MXT/_W1OI62WM$&VCE6&!)*$8#(P$B>43^]\3K!49PL5%+PFA[1!MH$6A:
M2N!8>D3^]\3KZV@9:(MH6P)OU$I(5DEX1`!H`R,!(B!8>43^]ZCK!49XL5%(
M,49X1/[W^?T"1@`H2M!!2^EH>T0;:`EHX%C^]Z+K/DM*27M$&VCE6`$B>40H
M1O[W].I&2@%&>D0H1O[WDNLW2P`B>T0;:$)(XU@Q1GA$@_AE(/[WTOT_3'Q$
MH&"@L4_TX''^]^3K0QP1*!B_`2M`V#I*+TMZ1--8&F@!FUI`3_```S31`[#P
MO6!H__<6_:!@`"CDT3)(>$3^]]CJ0W@`*XG0@N?^]\W_!T:8L1U+ZFA[1!MH
M$6@"1N!8_O=2ZSA&_O>^ZZOG%TM[1!MHX%C^]^SJB.<52R)*>T0;:'I$Z6A2
M:`EH$FC@6/[W/.N7Y_[WV.L<2@-&'$AZ1-+I`1)X1`EH_O>BZL)E``":90``
M?F4``&!E```X90``*&4```AE``":9```@F0``')D``#"9```(`$``&H/```8
M$0``!!$``.X0``"X#@``O!```,@0``!B#@``>F4``,)C``!P$```]F0``-ID
M```L$```3_2`7#"UK>L,#,SXZ`\I2BE+>D0$1BE(@[#36&E&>$0;:`&33_``
M`_[W,/UPL0-X`"L8OS`K#+\!(P`C@_`!`P`L#+\`(P/P`0-;N1Q*&DMZ1--8
M&F@!FUI`3_```R?1`[`PO2-X`"OPT"!&__>B^"\A!4;^]X;J`+%%'"A&_O>6
MZA!)!")Y1/[W<.H`*-W1#4H)2WI$TU@::`&;6D!/\``#!=$@1@.PO>@P0/[W
M=KW^]T#KMF(``"`!``"2#0``>&(``/(-```T8@```````$_T@%PMZ?!/K>L,
M#,SX>`[?^$0IW_A$.7I$TUC9L!MH5Y-/\``#@T8`\1P"!JE<,%+X!#L;NH)"
M0?@$/_C1#?$<#`BJW.D-3DBOW.D`!MSX/#``X`Y&'4;3:5+X!!]+0&-`0T!/
MZO-SET)T1C!&KD:38^_11_:9'MOI`C+<Z0!%V_@$H%-``^H*`X/J`@C;^`@P
MQ?:"+H/JN@;;^``P=$0>0-OX"#!U1%Y`V_@`,-SX&`!/ZK,)W/@(,(GJN@(!
MD]OX$#!P1!Q$V_@,,-SX(!`=1-OX`#`N1`3K\V1$1`&=!NOT8P+J!`;;^`@@
M=4051-SX#""&ZKH&-40"ZPX&!NNZ`@&2W/@0(`7K\V4"ZPX&W/@4('%$`NL.
M"`;K"0+<^!Q@`I)V1`;KM08#EMSX*&`(Z[0(=D0$EMSX+&#<^"0@=D0%EHGJ
MM`8>0(;J"0D!GD_JLP.Q1(/JM`8N0(;JM`8"G`GK]6DF1(/JM00&Z_EF!.H)
M!$_JN0D81%Q`B>JU`S-`1$2#ZK4#!.OV9`-$`^OT8(GJM@,C0`6=@^H)"`.;
M3^JT!)A$!)M)1`/K!`F$ZK8#`T"#ZK8#".OP:`M$`^OX883JL`,#Z@@#3^JX
M"')$7$"(ZK`#`NNV`@M`%$2#ZK`#!.OQ9$M$!>NP!0/K]&"(ZK$#W/@P("-`
M3^JT!(3JL09.]J$W<D2#Z@@#!D`K1(;JL08"ZP@%W/@T(`/K\&,N1(3JL`5R
M1!U``NNQ`F5`%43<^#@@!NOS87)$3^JS`Q1$W/@\((/JL`9R1`Y`!>OQ90+K
ML`*&ZK`&@^JQ`"A`)D180`;K]6001$_JM07<^$`@`.OT9H7JL0!R1"!`&D2`
MZK$`W/A$,!!$A>JT`G-$,D!J0`/KL0,31-SX2"!/ZK8!<D051-SX3"``Z_9@
M@>JT!G)$!D`#Z_!C`NNT`H;JM`:!ZK`$'$!,0!1$W/A0(,;VV6<Z1#5$5AC<
M^%00!>OS93E$3^JS`P'KL`Z#ZK`!:4!P&-SX6!`$Z_5D.43.&(/JM0'<^%PP
M`.OT8#M$84!/ZK0$<40#Z[4.A.JU`T-`]1C<^&`P`>OP83M$'AG<^&0PA.JP
M!`7K\64[1$Q`3^JQ`71$`^NP#H'JL`-K0/`8W/AH,`3K]60[1%X8W/AL,('J
MM0%A0#M$<41/ZK0.`.OT8`/KM0B.ZK4#0T#T&-SX<#`!Z_!A.T0#ZPX%W/AT
M,([JL`8$Z_%D.T1.0$_JL0$#Z[`.@>JP`V-`Z!C<^'@P1D0[1%T8@>JT`]SX
M?!`&Z_1F`.OV8#E$<T!/ZK8&<T0!Z[0.ANJT`4%`;!C<^(`02_;<0CE$C1G<
M^(00`^OP8X;JL`8$Z_-D.41>0$_JLP-V1`'KL`Z#ZK`!84!H&-SXB!`&Z_1F
M.43-&-SXC!"#ZK0#`.OV8#E$<T!/ZK8&<T0!Z[0.ANJT`4%`;!C<^)`0`^OP
M8SE$`>L&"-SXE!"&ZK`%!.OS9#E$74!/ZK,#`>NP!H/JL`%A0`CK`0#<^)@0
M=40Y1`7K]&4!ZP,.@^JT`]SXG!!K0`#K]6`S1$_JM04#Z_!CA>JP!CE$`>NT
M`5Y`#D3<^*`0R/8;<H7JM`011$1`#41T1-SXI!`$Z_-D3^JS`T/JL`<11`'K
ML`$G0`/JL``X0P;K]&8H1$/JM`4#ZK0'-4`]0PU$W/BH$`#K]F`11!E$W/BL
M,$_JM@9&ZK0'$T0#Z[0#!T`&ZK0$/$,%Z_!E#$1&ZK`!*4`&ZK`'#T/<^+00
M!.OU9!]$3^JU!=SXL#!%ZK`.$4031`'KL`$.Z@0.!>JP`!Y$3NH`#@?K]&>V
M1$7JM`8.Z_=@/D`%ZK0.1NH.!@Y$W/BX$$_JMP<11`U$W/B\$$?JM`X11`'K
MM`$.Z@`.!^JT!$[J!`X&Z_!FKD1'ZK`%#NOV9#5`!^JP#D7J#@4-1-SXP!!/
MZK8&$40/1-SXQ!!&ZK`.$40!Z[`!#NH$#@;JL`!.Z@`.!>OT9;Y$1NJT!P[K
M]6`O0`;JM`Y'Z@X'#T3<^,@03^JU!1%$#D3<^,P01>JT#A%$`>NT`0[J``X%
MZK0$3NH$#@?K\&>V1$7JL`8.Z_=D/D`%ZK`.1NH.!@Y$W/C0$$_JMP<11`U$
MW/C4$$?JL`X11`'KL`$.Z@0.!^JP`$[J``X&Z_1F1^JT`*Y$#NOV93!`!^JT
M#D#J#@!,\M83"$3<^-@03^JV!A%$`>L'#MSXW!``Z_5@$40!Z[0'1NJT`2E`
M!NJT!"%#1NJU!'%$!$`&ZK4.1.H.!`'K\&$\1`3K\6?<^.!`3^JP`!1$)D3<
M^.1`0.JU#A1$!.NU!`[J`0X`ZK4%3NH%#K9$0.JQ!@[K]V4^0`#JL0Y&Z@X&
M)D3<^.A`3^JW!Q1$!$3<^.P`S/9B(Q!$1^JQ`BI``.NQ``?JL0$10]SX\"`&
MZ_5F&D0"ZP<.W/CT("%$1^JU!`'K]F$'ZK4'&D0T0$_JM@8\0P+KM0>&ZK4"
M2D`@1`[K`@3<^/@@`.OQ8!I$E1F&ZK$&ANH``KX8W/C\(`3K\&0:1$_JL``"
MZ[$'@.JQ`F)`%43<^``A!NOT9AI$$1B`ZK0`@.H&`K@8W/@$(07K]F4:1$_J
MM@8"Z[0'ANJT`FI`$43<^`@A`.OU8!I$`NL&#H;JM0:&Z@`"`>OP9+D8W/@,
M(4_JL``:1`+KM0:`ZK4"8D`.ZP(%W/@0(0'K]&$:1!<8@.JT`(#J`0*P&-SX
M%"$%Z_%E&D1/ZK$!`NNT!H'JM`)J0+P8W/@8(0#K]6`:1%<8@>JU`8'J``*Q
M&-SX'"$$Z_!D&D1/ZK```NNU!H#JM0)B0+T8W/@@(0'K]&$:1!<8@.JT`(#J
M`0(%Z_%E%D1/ZK$!W/@D(8'JM`!H0!I$`NNT`CP8W/@H`0;K]6881`A$@>JU
M`7%`!.OV9`I$`NOT8=SX+"%/ZK8&&D0"Z[4'ANJU`F)`$$3<^#`A`.OQ8!I$
ME1F&ZK0&ANH!`KX8W/@T(4_JL0$:1`+KM`*!ZK0$1$`&Z_!F+$3;^`Q0!.OV
M9`7KM`7+^`Q0W.E.5QU$.T3;^`!P#42!ZK`!<4`[1$_JM@8#Z[`#"D2&ZK``
M`NOT88#J!`*H&(;JM`)*0!-$V_@((`#K\6`#Z_!CV_@00`+KL0)01,OI`##+
M^`@@"TH)2R9$>D3+^!!@TU@::%>;6D!/\``#`M%9L+WH\(_]]XCN`+_@80``
M(`$``,!8``!/](!<<+6MZPP,S/CP#V`@0O(!-4KVB33]]X+M1?)V1DWV_D$`
M(L;R177.]LUTP.D`5`BEU>D`1<#I!$7)]KH!P?(R!L9@@6""8<)E<+T`OZ_S
M`(#PX=+#`````$_T@%PMZ?!'K>L,#,SXX`\51H!&0VF*1M$`@FE;&$-A*+\!
M,L!M`NM5<LCX&"`(\1P'^+'`\4`$"/$<!ZQ".$2HORQ&4$54T@,9FD4HOPKK
M!`9)TU%&(D;]]Q+NV/A<,"-$0"O(^%PP.-%`1O_WZ/JR1BT;/RTCW51&"/%<
M"0KQ0`:G0BS23$4NT[)&.T8$\4`.U/@`P&!HH6CB:!`T=$7#^`#`6&"98-I@
M`_$0`_#10$9`/?_WQ/H_+0;Q0`;@W%=%$M,#V0KK!0.?0@S3*D911CA&_??4
M[<CX7%"]Z/"'LD;3V;="T=+_WGL9FD7NTO_>"NL$!JW9L$*KTO_>`+]/](!<
M+>GP0:WK#`S,^.@/3_"`#$MI`?$<!Y/Z@_C#\\4#BFD'^`/``3,X*PQ&!486
MND3=`"'#\4`"^!C]][#L($;_]WWZ."(`(3A&_?>H["!&Q.D5:/_W<_KC>"!&
M*W!CB&MP(V@;"JMP(VCK<.-Y*W'CB&MQ8V@;"JMQ8VCK<>-Z*W)CB6MRHV@;
M"JMRHVCK<N-[*W/CB6MSXV@;"JMSXVCK<^-\*W1CBFMT(VD;"JMT(VGK=+WH
M\$']]S^]`"'X&,/Q.`+]]VSLP><!M;WH`4!P1SX```!!````#````$$````1
M````00```"<```!!````-@```$$````#````00````8```!!````%0```$$`
M```/````00````X```!!````)@```$$````3````00```"D```!!`````@``
M`$$````9````00````H```!!````"P```$$``````````````"5S+R5S````
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%35``````4$%27U!2
M3T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@````!015),3$E"
M`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]'
M3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2
M``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@`````Q````;'-E
M96L@9F%I;&5D`````')E860@9F%I;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-4
M14T``"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(
M`````'!A<FP`````+G!A<@````!S:&]R="!R96%D```E<R5S8V%C:&4M)7,E
M<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````&````'!E
M<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#8S````56YA
M8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@`````M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)
M4@!435``+W1M<`````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O
M9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-
M04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@
M(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!
M1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY
M("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D
M8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M
M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I
M<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I
M('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?
M<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E
M>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I
M.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P
M96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP
M(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8
M(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T
M;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T
M;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA
M;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;
M4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P
M.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_
M.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N
M86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D
M<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R
M;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E
M<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD
M7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H
M<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!0
M05(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!
M0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*
M:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2![
M"F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]
M"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&
M2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A
M8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,
M17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%
M7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C
M=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@
M)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE
M(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,
M12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@
M<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N
M86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D[
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_
M.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#
M86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L
M"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U
M8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D
M;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD
M;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E
M7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF
M;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F
M24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F
M:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M
M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E
M96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD
M:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B
M.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+
M6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@
M<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]
M"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@
M(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N
M9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%0
M4%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y
M('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*
M<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL
M7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6
M(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%
M3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`
M05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI
M+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE
M;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@
M)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@
M>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I
M970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A
M73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD[
M"FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\
M.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P
M87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;
M17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A
M7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,[
M"B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@
M*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P
M:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL
M92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I
M92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q
M("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O
M=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@
M)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@
M>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*
M?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]
M"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]
M"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\
M9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]
M*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E
M;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D
M9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y
M+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@
M*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E
M<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[
M)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II
M9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS
M<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@
M)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F
M*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*
M;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@
M/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL
M"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D
M(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II
M<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@
M;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R
M:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?
M;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D
M9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#([
M"B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE
M(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD
M8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG
M=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#
M04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO
M861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!
M1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I
M;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@
M24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D
M:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A
M9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L
M("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S
M*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C
M:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M
M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^
M9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_
M<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK
M*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@
M/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C
M=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R
M+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE
M;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?
M;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T
M;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N
M86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q
M=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R
M.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V
M87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#
M;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!]
M.PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L
M87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U
M<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C
M86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R
M7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX[
M"GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?
M5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%
M35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U
M:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S
M97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@
M)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?
M9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F
M:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D
M("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE
M+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]
M?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO
M<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E
M;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D
M<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP
M(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT
M<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA
M;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B
M)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T
M96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D
M9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF
M("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S
M>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E
M>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-
M4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M
M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?
M9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O
M9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2![
M"F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R
M;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN
M(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*
M<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X
M<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF
M="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G
M<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S
M("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I
M9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN
M8P````!#04-(10``/@```$$````,````00```!$```!!````)P```$$````V
M````00````,```!!````!@```$$````5````00````\```!!````#@```$$`
M```F````00```!,```!!````*0```$$````"````00```!D```!!````"@``
M`$$````+````00``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!)%@``Y14```$````6`P``
M`0```"$#```=````=00```P```!9$```#0```%4X```9````S(T``!L````$
M````&@```-"-```<````!````/7^_V]P`0``!0```/P(```&````7`(```H`
M``"3!```"P```!`````5``````````,```#$C@```@```-@!```4````$0``
M`!<```"`#@``$0```)`-```2````\````!,````(````'@````@```#[__]O
M`0``"/K__V\0````````````````````````````````````````````````
M`````````-2-`````````````&`0``!@$```8!```&`0``!@$```8!```&`0
M``!@$```8!```&`0``!@$```8!```&`0``!@$```8!```&`0``!@$```8!``
M`&`0``!@$```8!```&`0``!@$```8!```&`0``!@$```8!```&`0``!@$```
M8!```&`0``!@$```8!```&`0``!@$```8!```&`0``!@$```8!```&`0``!@
M$```8!```&`0``!@$```8!```&`0``!@$```8!```&`0``!@$```8!```&`0
M``!@$```8!```&`0``!@$```8!```&`0``!@$```21,`````````````53@`
M````````````61``````````````````````````````````````````````
M````````````D```"E!!4BYP;0H`````)#P``#@Y````````^#D``/PY```8
M/```0#D``"`\````````!#P```P\````````+#P``$=#0SH@*$%L<&EN92`Q
M,RXR+C%?9VET,C`R,S$P,30I(#$S+C(N,2`R,#(S,3`Q-`!'0T,Z("A!;'!I
M;F4@,3,N,BXQ7V=I=#(P,C0P,S`Y*2`Q,RXR+C$@,C`R-#`S,#D`03(```!A
M96%B:0`!*`````4W+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1H"'`$>`B(!
M`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA
M<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT
M97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI
M7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-
M+F%T=')I8G5T97,`````````````````````````````````````````````
M``````````````L````!`````@```#0!```T`0``&````````````````0``
M```````3````!P````(```!,`0``3`$``"0```````````````0`````````
M)@```/;__V\"````<`$``'`!``#L````!``````````$````!````#`````+
M`````@```%P"``!<`@``H`8```4````#````!````!`````X`````P````(`
M``#\"```_`@``),$``````````````$`````````0`````D````"````D`T`
M`)`-``#P````!``````````$````"````$D````)````0@```(`.``"`#@``
MV`$```0````1````!`````@```!2`````0````8```!8$```6!````@`````
M``````````(`````````30````$````&````8!```&`0``#D`@``````````
M```$````!````%@````!````!@```$@3``!($P``#"4`````````````"```
M``````!>`````0````8```!4.```5#@```@```````````````(`````````
M9`````$````"````7#@``%PX``#D00`````````````$`````````&P````!
M`````@```$!Z``!`>@``!```````````````!`````````!V````#@````,`
M``#,C0``S'T```0```````````````0````$````@@````\````#````T(T`
M`-!]```$```````````````$````!````(X````&`````P```-2-``#4?0``
M\`````4`````````!`````@```"7`````0````,```#$C@``Q'X``#P!````
M``````````0````$````G`````$````#`````)````"```!$````````````
M```$`````````*(````(`````P```$20``!$@```+```````````````!```
M``````"G`````0```#``````````1(```&(```````````````$````!````
ML`````,``'```````````*:````S```````````````!``````````$````#
C``````````````#9@```P````````````````0``````````
